@@ -530,7 +530,7 @@ def run(
         rename_effect = True
     else:
         rename_effect = False
-    if dna_or_rna == "RNA":
+    if dna_or_rna == "RNA" or "strand" in columns_index_mapper:
         strandness = True
 
     # The max version of GRCm38 is 102
@@ -595,7 +595,15 @@ def run(
             else:
                 input_header = input_file.readline().strip().split()
         else:
-            input_header = ["chrom", "pos", "strand", "ref", "alt"]
+            if input.endswith(".gz"):
+                input_header = ["."] * len(
+                    input_file.readline().decode().strip().split()
+                )
+            else:
+                input_header = ["."] * len(
+                    input_file.readline().strip().split()
+                )
+            input_file.seek(0)
         header_line = "\t".join(input_header + Annot().get_names()) + "\n"
         if output.endswith(".gz"):
             header_line = header_line.encode()
